import DefaultAPIHandler from './default';
import { Asset, Assets } from '../../../types';
export type Action = {
    id: string;
    name: string;
    created_at: string;
    updated_at: string;
    deployed?: boolean;
    supported_triggers: {
        id: string;
        version: string;
        status?: string;
    }[];
    code?: string;
    dependencies?: [];
    runtime?: string;
    status?: string;
    secrets?: {
        name: string;
        value: string;
    }[];
    all_changes_deployed?: boolean;
    installed_integration_id?: string;
    integration?: Object;
};
export declare const schema: {
    type: string;
    items: {
        type: string;
        required: string[];
        additionalProperties: boolean;
        properties: {
            code: {
                type: string;
                default: string;
            };
            runtime: {
                type: string;
            };
            dependencies: {
                type: string;
                items: {
                    type: string;
                    additionalProperties: boolean;
                    properties: {
                        name: {
                            type: string;
                        };
                        version: {
                            type: string;
                        };
                        registry_url: {
                            type: string;
                        };
                    };
                };
            };
            secrets: {
                type: string;
                items: {
                    type: string;
                    properties: {
                        name: {
                            type: string;
                        };
                        value: {
                            type: string;
                        };
                        updated_at: {
                            type: string;
                            format: string;
                        };
                    };
                };
            };
            name: {
                type: string;
                default: string;
            };
            supported_triggers: {
                type: string;
                items: {
                    type: string;
                    properties: {
                        id: {
                            type: string;
                            default: string;
                        };
                        version: {
                            type: string;
                        };
                        url: {
                            type: string;
                        };
                    };
                };
            };
            deployed: {
                type: string;
            };
            status: {
                type: string;
            };
        };
    };
};
export declare function isMarketplaceAction(action: Action): boolean;
export default class ActionHandler extends DefaultAPIHandler {
    existing: Action[] | null;
    constructor(options: DefaultAPIHandler);
    createAction(action: Action): Promise<Action>;
    deleteAction(action: Action): Promise<void | never[]>;
    objString(action: any): string;
    deployActions(actions: any): Promise<void>;
    deployAction(action: any): Promise<void>;
    actionChanges(action: any, found: any): Promise<Asset>;
    getType(): Promise<Asset[] | null>;
    processChanges(assets: Assets): Promise<void>;
}
